//
//  LabelScene.cpp
//  label
//
//  Created by Reza Ghobadinic on 2019-11-03.
//

#include "LabelScene.h"

Scene* LabelScene::createScene()
{
    return LabelScene::create();
}

bool LabelScene::init()
{
    if ( !Scene::init() )
    {
        return false;
    }
    
    // Screen coordinates
    auto visibleSize = Director::getInstance()->getVisibleSize();   // Screen's visible size
    Vec2 origin = Director::getInstance()->getVisibleOrigin();      // Screen's visible origin
    float x = origin.x + visibleSize.width * 0.5;                   // X for the center of the screen
    
    // System Font
    auto label_sys = Label::createWithSystemFont("This is a System font.", "Arial", 30.0);
    label_sys->setPosition(x, 250);
    this->addChild(label_sys);
    
    // TTF Font
    auto label_ttf = Label::createWithTTF("This is a True Type font.", "fonts/Windsong.ttf", 30.0);
    label_ttf->setPosition(x, 200);
    this->addChild(label_ttf);
    
    // OTF Font
    auto label_otf = Label::createWithTTF("This is an Open Type font.", "fonts/GreatVibes.otf", 30.0);
    label_otf->setPosition(x, 150);
    this->addChild(label_otf);
    
    // Font Config
    TTFConfig config;
    config.fontFilePath = "fonts/Windsong.ttf";
    config.fontSize = 30;
    config.outlineSize  = 0;
    config.distanceFieldEnabled = false;
    config.glyphs = GlyphCollection::DYNAMIC;
    config.customGlyphs = nullptr;

    auto label_con = Label::createWithTTF(config, "This is a True Type font using TTFConfig.");
    label_con->setPosition(x, 100);
    this->addChild(label_con);
    
    // Bitmap Font
    auto label_bmp = Label::createWithBMFont("fonts/ScoreBoardFont.fnt", "This is a Bitmap font.");
    label_bmp->setPosition(x, 50);
    this->addChild(label_bmp);
    
    // Effects only work on System and TTF/OTF fonts
    label_sys->enableOutline(Color4B::RED, 2);
    label_ttf->enableShadow(Color4B::RED, Size(5,-5), 0);
    label_otf->enableGlow(Color4B::RED);
    
    // Letter sprite access only works on Bitmap fonts
    auto sprite1 = label_bmp->getLetter(0);
    sprite1->setScale(2.0);

    //auto label = Label::createWithSystemFont("First Line\nSecond Line\nThird Line", "Arial", 30);
    //label->setPosition(x, 200);
    //label->setHorizontalAlignment(TextHAlignment::CENTER);
    //this->addChild(label);
        
    return true;
}
